@@ -236,12 +236,12 @@ class DirectoryWatcher extends EventEmitter {
 		});
 	}
 
-	setDirectory(directoryPath, mtime, initial, type) {
+	setDirectory(directoryPath, birthtime, initial, type) {
 		if (this.checkIgnore(directoryPath)) return;
 		if (directoryPath === this.path) {
 			if (!initial) {
 				this.forEachWatcher(this.path, w =>
-					w.emit("change", directoryPath, mtime, type, initial)
+					w.emit("change", directoryPath, birthtime, type, initial)
 				);
 			}
 		} else {
@@ -258,14 +258,14 @@ class DirectoryWatcher extends EventEmitter {
 
 				let safeTime;
 				if (initial) {
-					safeTime = Math.min(now, mtime) + FS_ACCURACY;
+					safeTime = Math.min(now, birthtime) + FS_ACCURACY;
 				} else {
 					safeTime = now;
 				}
 
 				this.forEachWatcher(directoryPath, w => {
 					if (!initial || w.checkStartTime(safeTime, false)) {
-						w.emit("change", mtime, type);
+						w.emit("change", birthtime, type);
 					}
 				});
 				this.forEachWatcher(this.path, w => {
@@ -349,7 +349,22 @@ class DirectoryWatcher extends EventEmitter {
 			if (safeTime >= startTime) {
 				process.nextTick(() => {
 					if (this.closed) return;
-					watcher.emit("change", safeTime);
+					if (filePath === this.path) {
+						watcher.emit(
+							"change",
+							filePath,
+							safeTime,
+							"watch (outdated on attach)",
+							true
+						);
+					} else {
+						watcher.emit(
+							"change",
+							safeTime,
+							"watch (outdated on attach)",
+							true
+						);
+					}
 				});
 			}
 		} else if (this.initialScan) {
@@ -422,7 +437,7 @@ class DirectoryWatcher extends EventEmitter {
 					} else if (stats.isDirectory()) {
 						this.setDirectory(
 							filePath,
-							+stats.mtime || +stats.ctime || 1,
+							+stats.birthtime || 1,
 							false,
 							eventType
 						);
@@ -654,7 +669,7 @@ class DirectoryWatcher extends EventEmitter {
 							if (!initial || !this.directories.has(itemPath))
 								this.setDirectory(
 									itemPath,
-									+stats.mtime || +stats.ctime || 1,
+									+stats.birthtime || 1,
 									initial,
 									"scan (dir)"
 								);
